# crzp
SYSNET CRŽP connector REST API (IPPC & CITES extension)

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.1.0
- Package version: 1.1.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install sysnet-crzp
```

Then import the package:
```python
import crzp 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import crzp
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import crzp
from crzp.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = crzp.DevelopersApi(crzp.ApiClient(configuration))

try:
    # get service info
    api_response = api_instance.info_api()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DevelopersApi->info_api: %s\n" % e)

# Configure API key authorization: apiKey
configuration = crzp.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = crzp.DevelopersApi(crzp.ApiClient(configuration))

try:
    # get extended service info
    api_response = api_instance.info_ext_api()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DevelopersApi->info_ext_api: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://service-test.sysnet.cz/crzp/1.1.0*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DevelopersApi* | [**info_api**](docs/DevelopersApi.md#info_api) | **GET** /info | get service info
*DevelopersApi* | [**info_ext_api**](docs/DevelopersApi.md#info_ext_api) | **GET** /info-ext | get extended service info
*IppcApi* | [**irz_facility_api**](docs/IppcApi.md#irz_facility_api) | **GET** /irz-facility/{identifier} | Get IRZ facility detail
*IppcApi* | [**irz_facility_ft_api**](docs/IppcApi.md#irz_facility_ft_api) | **GET** /irz-facility | Get all IRZ facilities by FT query
*IppcApi* | [**irz_facility_ft_paging_api**](docs/IppcApi.md#irz_facility_ft_paging_api) | **GET** /irz-facility/{begin} | Get all IRZ facilities by FT query (pagination)
*IppcApi* | [**irz_facility_operation_code_api**](docs/IppcApi.md#irz_facility_operation_code_api) | **GET** /irz-facility-operation/facility/{code} | Get all IRZ facility operations by facility identifier
*IppcApi* | [**irz_facility_operation_ft_api**](docs/IppcApi.md#irz_facility_operation_ft_api) | **GET** /irz-facility-operation | Get all IRZ facility operations by FT query
*IppcApi* | [**irz_facility_operation_ft_paging_api**](docs/IppcApi.md#irz_facility_operation_ft_paging_api) | **GET** /irz-facility-operation/{begin} | Get all IRZ facility operations by FT query (pagination)
*IppcApi* | [**irz_facility_pid_api**](docs/IppcApi.md#irz_facility_pid_api) | **GET** /irz-facility/ippc/{pid} | Get all IRZ facilities by IPPC PID
*PublicApi* | [**role_holder_api**](docs/PublicApi.md#role_holder_api) | **GET** /role-holder/{object_type}/{code} | Get all role holders
*PublicApi* | [**role_holder_ft_api**](docs/PublicApi.md#role_holder_ft_api) | **GET** /role-holder/{object_type} | Get all roles and holders by FT query
*PublicApi* | [**role_holder_ft_paging_api**](docs/PublicApi.md#role_holder_ft_paging_api) | **GET** /role-holder/{object_type}/{begin} | Get all roles and holders by FT query (pagination)
*PublicApi* | [**role_holder_paging_api**](docs/PublicApi.md#role_holder_paging_api) | **GET** /role-holder/{object_type}/{code}/{begin} | Get all role holders (pagination)
*PublicApi* | [**subject_api**](docs/PublicApi.md#subject_api) | **GET** /subject/{identifier} | Get user detail
*PublicApi* | [**user_api**](docs/PublicApi.md#user_api) | **GET** /user/{identifier} | Get user detail
*PublicApi* | [**user_context_api**](docs/PublicApi.md#user_context_api) | **GET** /user-context/{identifier} | Get user context

## Documentation For Models

 - [Address](docs/Address.md)
 - [AgendaReference](docs/AgendaReference.md)
 - [AgendaSubjectDetail](docs/AgendaSubjectDetail.md)
 - [ContextRole](docs/ContextRole.md)
 - [ContextSubject](docs/ContextSubject.md)
 - [ContextSystem](docs/ContextSystem.md)
 - [DictionaryReference](docs/DictionaryReference.md)
 - [EuState](docs/EuState.md)
 - [GeoPoint](docs/GeoPoint.md)
 - [GeoPointJtsk](docs/GeoPointJtsk.md)
 - [HolderReference](docs/HolderReference.md)
 - [IdentityDocumentDetail](docs/IdentityDocumentDetail.md)
 - [IppcActivity](docs/IppcActivity.md)
 - [IrzActivityRecord](docs/IrzActivityRecord.md)
 - [IrzEmissionsTradingSystem](docs/IrzEmissionsTradingSystem.md)
 - [IrzFacilities](docs/IrzFacilities.md)
 - [IrzFacilityDetail](docs/IrzFacilityDetail.md)
 - [IrzFacilityItem](docs/IrzFacilityItem.md)
 - [IrzFacilityOperationItem](docs/IrzFacilityOperationItem.md)
 - [IrzFacilityOperations](docs/IrzFacilityOperations.md)
 - [IrzFacilityReference](docs/IrzFacilityReference.md)
 - [LegalEntityPart](docs/LegalEntityPart.md)
 - [NamedReference](docs/NamedReference.md)
 - [OneOfHolderReferenceRoleHolder](docs/OneOfHolderReferenceRoleHolder.md)
 - [PersonPart](docs/PersonPart.md)
 - [RoleHolderObjectType](docs/RoleHolderObjectType.md)
 - [RoleHolders](docs/RoleHolders.md)
 - [RoleReference](docs/RoleReference.md)
 - [RuianReference](docs/RuianReference.md)
 - [SubjectDetail](docs/SubjectDetail.md)
 - [SubjectReference](docs/SubjectReference.md)
 - [SystemReference](docs/SystemReference.md)
 - [SystemRoleContext](docs/SystemRoleContext.md)
 - [User](docs/User.md)
 - [UserContext](docs/UserContext.md)
 - [UserReference](docs/UserReference.md)

## Documentation For Authorization


## apiKey

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header


## Author

info@sysnet.cz
